==> cego-2.18.7.tar.gz: cego-2.18.7/src/CegoJoinObject.h <==
#ifndef _CEGOJOINOBJECT_H_INCLUDED_
#define _CEGOJOINOBJECT_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoJoinObject.h
// ----------------
// Cego join object class definition
//     
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2010 Bjoern Lemke
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: CegoJoinObject
// 
// Description: Cego join object structure
//
// Status: QG-2.6
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include <lfcbase/ListT.h>
#include <lfcbase/Chain.h>

// cego includes
#include "CegoField.h"
#include "CegoContentObject.h"
#include "CegoPredDesc.h"

class CegoJoinObject : public CegoContentObject {

 public:

    enum JoinType { INNER, LEFTOUTER, RIGHTOUTER  };

    CegoJoinObject();
    CegoJoinObject(const CegoJoinObject& jo);
    CegoJoinObject( Element *pJO );
    CegoJoinObject( JoinType joinType, CegoContentObject *pLeftObject, CegoContentObject *pRightObject, CegoPredDesc *pPred );
	
    ~CegoJoinObject();
    
    int getEntrySize() const;
    void encode(char *buf);
    void decode(char *buf);

    void setSchema(const ListT<CegoField>& schema);   

    JoinType getJoinType();

    CegoContentObject* getLeftObject();
    CegoContentObject* getRightObject();
    CegoPredDesc* getPredDesc();
    void getPredList(ListT<CegoPredDesc*>& predList);

    void setEmpty();
    
    CegoJoinObject& operator = ( const CegoJoinObject& jo);
    bool operator == ( const CegoJoinObject& jo);
    
    Chain toChain() const;
    CegoContentObject* clone(bool isAttrRef = false);

    Element* getElement() const;
    void putElement(Element* pElement);
    Chain getFormatted() const;

 private:

    Chain fill(const Chain& s, int num) const;

    JoinType _joinType;
    CegoContentObject *_pLeftObject;
    CegoContentObject *_pRightObject;
    CegoPredDesc *_pPred;
    
};

#endif

==> cego-2.31.5.tar.gz: cego-2.31.5/src/CegoJoinObject.h <==
#ifndef _CEGOJOINOBJECT_H_INCLUDED_
#define _CEGOJOINOBJECT_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoJoinObject.h
// ----------------
// Cego join object class definition
//     
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2016 Bjoern Lemke
//
// INTERFACE MODULE
//
// Class: CegoJoinObject
// 
// Description: Cego join object container class
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include <lfcbase/ListT.h>
#include <lfcbase/Chain.h>

// cego includes
#include "CegoField.h"
#include "CegoContentObject.h"
#include "CegoPredDesc.h"

class CegoJoinObject : public CegoContentObject {

 public:

    enum JoinType { INNER, LEFTOUTER, RIGHTOUTER  };

    CegoJoinObject();
    CegoJoinObject(const CegoJoinObject& jo);
    CegoJoinObject( Element *pJO );
    CegoJoinObject( JoinType joinType, CegoContentObject *pLeftObject, CegoContentObject *pRightObject, CegoPredDesc *pPred );
	
    ~CegoJoinObject();
    
    int getEntrySize() const;
    void encode(char *buf);
    void decode(char *buf);

    void setSchema(const ListT<CegoField>& schema);   

    JoinType getJoinType();

    CegoContentObject* getLeftObject();
    CegoContentObject* getRightObject();
    CegoPredDesc* getPredDesc();
    void getPredList(ListT<CegoPredDesc*>& predList);

    void setEmpty();
    
    CegoJoinObject& operator = ( const CegoJoinObject& jo);
    bool operator == ( const CegoJoinObject& jo);

    Chain getId() const;
    Chain toChain() const;
    CegoContentObject* clone(bool isAttrRef = false);

    Element* getElement() const;
    void putElement(Element* pElement);
    Chain getFormatted() const;

 private:

    Chain fill(const Chain& s, int num) const;

    JoinType _joinType;
    CegoContentObject *_pLeftObject;
    CegoContentObject *_pRightObject;
    CegoPredDesc *_pPred;
    
};
#endif
